Getbook
=======

Chinese websites parsers for getbook_.

.. _getbook: https://github.com/lepture/getbook

.. image:: https://img.shields.io/badge/donate-lepture-ff69b4.svg
   :target: https://lepture.com/donate
   :alt: Donate lepture

Installation
------------

Install with pip::

    $ pip install getbook-chinese

Usage
-----

Create EPUB book::

    $ getbook -u https://www.kanunu8.com/wuxia/201102/1606.html

Create MOBI book::

    $ getbook --mobi -u https://www.kanunu8.com/wuxia/201102/1606.html
